@@ -11,17 +11,47 @@ from .genericmetadata import GenericMetadata
 
 class ComicInfoXml:
 
-    writer_synonyms = ["writer", "plotter", "scripter"]
-    penciller_synonyms = ["artist", "penciller", "penciler", "breakdowns"]
-    inker_synonyms = ["inker", "artist", "finishes"]
-    colorist_synonyms = ["colorist", "colourist", "colorer", "colourer"]
+    writer_synonyms = ["writer", "plotter", "scripter", "script", "story", "plot"]
+    penciller_synonyms = [
+        "artist",
+        "breakdowns",
+        "illustrator",
+        "layouts",
+        "penciller",
+        "penciler",
+    ]
+    inker_synonyms = [
+        "artist",
+        "embellisher",
+        "finishes",
+        "illustrator",
+        "ink assists",
+        "inker",
+    ]
+    colorist_synonyms = [
+        "colorist",
+        "colourist",
+        "colorer",
+        "colourer",
+        "color assists",
+        "color flats",
+    ]
     letterer_synonyms = ["letterer"]
     cover_synonyms = ["cover", "covers", "coverartist", "cover artist"]
-    editor_synonyms = ["editor"]
+    editor_synonyms = [
+        "assistant editor",
+        "associate editor",
+        "consulting editor",
+        "editor",
+        "editor in chief",
+        "executive editor",
+        "group editor",
+        "senior editor",
+        "supervising editor",
+    ]
 
-    def getParseableCredits(self):
-        parsable_credits = []
-        parsable_credits.extend(self.writer_synonyms)
+    def get_parseable_credits(self):
+        parsable_credits = list(self.writer_synonyms)
         parsable_credits.extend(self.penciller_synonyms)
         parsable_credits.extend(self.inker_synonyms)
         parsable_credits.extend(self.colorist_synonyms)
@@ -30,23 +60,23 @@ class ComicInfoXml:
         parsable_credits.extend(self.editor_synonyms)
         return parsable_credits
 
-    def metadataFromString(self, string):
+    def metadata_from_string(self, string):
 
         tree = ET.ElementTree(ET.fromstring(string))
-        return self.convertXMLToMetadata(tree)
+        return self.convert_xml_to_metadata(tree)
 
-    def stringFromMetadata(self, metadata):
+    def string_from_metadata(self, metadata):
 
         header = '<?xml version="1.0"?>\n'
 
-        tree = self.convertMetadataToXML(self, metadata)
+        tree = self.convert_metadata_to_xml(self, metadata)
         tree_str = ET.tostring(tree.getroot()).decode()
         return header + tree_str
 
     def indent(self, elem, level=0):
         # for making the XML output readable
         i = "\n" + level * "  "
-        if len(elem):
+        if elem:
             if not elem.text or not elem.text.strip():
                 elem.text = i + "  "
             if not elem.tail or not elem.tail.strip():
@@ -59,10 +89,7 @@ class ComicInfoXml:
             if level and (not elem.tail or not elem.tail.strip()):
                 elem.tail = i
 
-    def convertMetadataToXML(self, filename, metadata):
-
-        # shorthand for the metadata
-        md = metadata
+    def convert_metadata_to_xml(self, filename, metadata):
 
         # build a tree structure
         root = ET.Element("ComicInfo")
@@ -74,21 +101,21 @@ class ComicInfoXml:
             if md_entry is not None:
                 ET.SubElement(root, cix_entry).text = "{0}".format(md_entry)
 
-        assign("Title", md.title)
-        assign("Series", md.series)
-        assign("Number", md.issue)
-        assign("Count", md.issueCount)
-        assign("Volume", md.volume)
-        assign("AlternateSeries", md.alternateSeries)
-        assign("AlternateNumber", md.alternateNumber)
-        assign("StoryArc", md.storyArc)
-        assign("SeriesGroup", md.seriesGroup)
-        assign("AlternateCount", md.alternateCount)
-        assign("Summary", md.comments)
-        assign("Notes", md.notes)
-        assign("Year", md.year)
-        assign("Month", md.month)
-        assign("Day", md.day)
+        assign("Title", metadata.title)
+        assign("Series", metadata.series)
+        assign("Number", metadata.issue)
+        assign("Count", metadata.issue_count)
+        assign("Volume", metadata.volume)
+        assign("AlternateSeries", metadata.alternate_series)
+        assign("AlternateNumber", metadata.alternate_number)
+        assign("StoryArc", metadata.story_arc)
+        assign("SeriesGroup", metadata.series_group)
+        assign("AlternateCount", metadata.alternate_count)
+        assign("Summary", metadata.comments)
+        assign("Notes", metadata.notes)
+        assign("Year", metadata.year)
+        assign("Month", metadata.month)
+        assign("Day", metadata.day)
 
         # need to specially process the credits, since they are structured
         # differently than CIX
@@ -128,52 +155,52 @@ class ComicInfoXml:
         # second, convert each list to string, and add to XML struct
         if len(credit_writer_list) > 0:
             node = ET.SubElement(root, "Writer")
-            node.text = utils.listToString(credit_writer_list)
+            node.text = utils.list_to_string(credit_writer_list)
 
         if len(credit_penciller_list) > 0:
             node = ET.SubElement(root, "Penciller")
-            node.text = utils.listToString(credit_penciller_list)
+            node.text = utils.list_to_string(credit_penciller_list)
 
         if len(credit_inker_list) > 0:
             node = ET.SubElement(root, "Inker")
-            node.text = utils.listToString(credit_inker_list)
+            node.text = utils.list_to_string(credit_inker_list)
 
         if len(credit_colorist_list) > 0:
             node = ET.SubElement(root, "Colorist")
-            node.text = utils.listToString(credit_colorist_list)
+            node.text = utils.list_to_string(credit_colorist_list)
 
         if len(credit_letterer_list) > 0:
             node = ET.SubElement(root, "Letterer")
-            node.text = utils.listToString(credit_letterer_list)
+            node.text = utils.list_to_string(credit_letterer_list)
 
         if len(credit_cover_list) > 0:
             node = ET.SubElement(root, "CoverArtist")
-            node.text = utils.listToString(credit_cover_list)
+            node.text = utils.list_to_string(credit_cover_list)
 
         if len(credit_editor_list) > 0:
             node = ET.SubElement(root, "Editor")
-            node.text = utils.listToString(credit_editor_list)
+            node.text = utils.list_to_string(credit_editor_list)
 
-        assign("Publisher", md.publisher)
-        assign("Imprint", md.imprint)
-        assign("Genre", md.genre)
-        assign("Web", md.webLink)
-        assign("PageCount", md.pageCount)
-        assign("LanguageISO", md.language)
-        assign("Format", md.format)
-        assign("AgeRating", md.maturityRating)
-        if md.blackAndWhite is not None and md.blackAndWhite:
+        assign("Publisher", metadata.publisher)
+        assign("Imprint", metadata.imprint)
+        assign("Genre", metadata.genre)
+        assign("Web", metadata.web_link)
+        assign("PageCount", metadata.page_count)
+        assign("LanguageISO", metadata.language)
+        assign("Format", metadata.format)
+        assign("AgeRating", metadata.maturity_rating)
+        if metadata.black_and_white is not None and metadata.black_and_white:
             ET.SubElement(root, "BlackAndWhite").text = "Yes"
-        assign("Manga", md.manga)
-        assign("Characters", md.characters)
-        assign("Teams", md.teams)
-        assign("Locations", md.locations)
-        assign("ScanInformation", md.scanInfo)
+        assign("Manga", metadata.manga)
+        assign("Characters", metadata.characters)
+        assign("Teams", metadata.teams)
+        assign("Locations", metadata.locations)
+        assign("ScanInformation", metadata.scan_info)
 
         #  loop and add the page entries under pages node
-        if len(md.pages) > 0:
+        if len(metadata.pages) > 0:
             pages_node = ET.SubElement(root, "Pages")
-            for page_dict in md.pages:
+            for page_dict in metadata.pages:
                 page_node = ET.SubElement(pages_node, "Page")
                 page_node.attrib = page_dict
 
@@ -185,7 +212,7 @@ class ComicInfoXml:
         return tree
 
     @classmethod
-    def convertXMLToMetadata(cls, tree):
+    def convert_xml_to_metadata(cls, tree):
 
         root = tree.getroot()
 
@@ -193,7 +220,6 @@ class ComicInfoXml:
             raise ValueError("Metadata is not ComicInfo format")
 
         metadata = GenericMetadata()
-        md = metadata
 
         # Helper function
         def xlate(tag):
@@ -203,57 +229,57 @@ class ComicInfoXml:
             else:
                 return None
 
-        md.series = xlate("Series")
-        md.title = xlate("Title")
-        md.issue = xlate("Number")
-        md.issueCount = xlate("Count")
-        md.volume = xlate("Volume")
-        md.alternateSeries = xlate("AlternateSeries")
-        md.alternateNumber = xlate("AlternateNumber")
-        md.alternateCount = xlate("AlternateCount")
-        md.comments = xlate("Summary")
-        md.notes = xlate("Notes")
-        md.year = xlate("Year")
-        md.month = xlate("Month")
-        md.day = xlate("Day")
-        md.publisher = xlate("Publisher")
-        md.imprint = xlate("Imprint")
-        md.genre = xlate("Genre")
-        md.webLink = xlate("Web")
-        md.language = xlate("LanguageISO")
-        md.format = xlate("Format")
-        md.manga = xlate("Manga")
-        md.characters = xlate("Characters")
-        md.teams = xlate("Teams")
-        md.locations = xlate("Locations")
-        md.pageCount = xlate("PageCount")
-        md.scanInfo = xlate("ScanInformation")
-        md.storyArc = xlate("StoryArc")
-        md.seriesGroup = xlate("SeriesGroup")
-        md.maturityRating = xlate("AgeRating")
+        metadata.series = xlate("Series")
+        metadata.title = xlate("Title")
+        metadata.issue = xlate("Number")
+        metadata.issue_count = xlate("Count")
+        metadata.volume = xlate("Volume")
+        metadata.alternate_series = xlate("AlternateSeries")
+        metadata.alternate_number = xlate("AlternateNumber")
+        metadata.alternate_count = xlate("AlternateCount")
+        metadata.comments = xlate("Summary")
+        metadata.notes = xlate("Notes")
+        metadata.year = xlate("Year")
+        metadata.month = xlate("Month")
+        metadata.day = xlate("Day")
+        metadata.publisher = xlate("Publisher")
+        metadata.imprint = xlate("Imprint")
+        metadata.genre = xlate("Genre")
+        metadata.web_link = xlate("Web")
+        metadata.language = xlate("LanguageISO")
+        metadata.format = xlate("Format")
+        metadata.manga = xlate("Manga")
+        metadata.characters = xlate("Characters")
+        metadata.teams = xlate("Teams")
+        metadata.locations = xlate("Locations")
+        metadata.page_count = xlate("PageCount")
+        metadata.scan_info = xlate("ScanInformation")
+        metadata.story_arc = xlate("StoryArc")
+        metadata.series_group = xlate("SeriesGroup")
+        metadata.maturity_rating = xlate("AgeRating")
 
         tmp = xlate("BlackAndWhite")
-        md.blackAndWhite = False
+        metadata.black_and_white = False
         if tmp is not None and tmp.lower() in ["yes", "true", "1"]:
-            md.blackAndWhite = True
+            metadata.black_and_white = True
         # Now extract the credit info
-        for n in root:
+        for credit_node in root:
             if (
-                n.tag == "Writer"
-                or n.tag == "Penciller"
-                or n.tag == "Inker"
-                or n.tag == "Colorist"
-                or n.tag == "Letterer"
-                or n.tag == "Editor"
+                credit_node.tag == "Writer"
+                or credit_node.tag == "Penciller"
+                or credit_node.tag == "Inker"
+                or credit_node.tag == "Colorist"
+                or credit_node.tag == "Letterer"
+                or credit_node.tag == "Editor"
             ):
-                if n.text is not None:
-                    for name in n.text.split(","):
-                        metadata.addCredit(name.strip(), n.tag)
+                if credit_node.text is not None:
+                    for name in credit_node.text.split(","):
+                        metadata.add_credit(name.strip(), credit_node.tag)
 
-            if n.tag == "CoverArtist":
-                if n.text is not None:
-                    for name in n.text.split(","):
-                        metadata.addCredit(name.strip(), "Cover")
+            if credit_node.tag == "CoverArtist":
+                if credit_node.text is not None:
+                    for name in credit_node.text.split(","):
+                        metadata.add_credit(name.strip(), "Cover")
 
         # parse page data now
         pages_node = root.find("Pages")
@@ -266,13 +292,13 @@ class ComicInfoXml:
 
         return metadata
 
-    def writeToExternalFile(self, filename, metadata):
+    def write_to_external_file(self, filename, metadata):
 
-        tree = self.convertMetadataToXML(self, metadata)
+        tree = self.convert_metadata_to_xml(self, metadata)
         # ET.dump(tree)
         tree.write(filename, encoding="utf-8")
 
-    def readFromExternalFile(self, filename):
+    def read_from_external_file(self, filename):
 
         tree = ET.parse(filename)
-        return self.convertXMLToMetadata(tree)
+        return self.convert_xml_to_metadata(tree)
